; Quick check of the wavelengths for the single-order movie mode

pro wavelengthso
@include

; read an arc file
  calso, eoccal, flat, arc, box=box

; read the line list
  res_scale = 5000
  slitw_arc = 3.0
  slitw_pix = slitw_arc/0.15
  lines = rdll(filepath('lines.dat',ROOT_DIR=reddatadir),$
                RES=res_scale/slitw_pix,THRESH=3,/VACUUM)


; inputs for wavecal
  x = findgen(512)
  spec = total(arc, 2)
  gain = 13. ; electron/DN
  var = spec/gain
  spectra = reform( [spec,var], 512,2,1)
  norders = 1
  naps = 1
  ltop = reform([-4438.5844, 1491.9264], 2,1)
  pixoffset = 0.
  orders = [6]
  homeorder = 6
  FWHM = slitw_pix
  disdeg = 3
  orderdeg = 2
  robustthresh = 4.0

  plotlinefind = 1
  

; begin "borrowing" from wavecal
rmss     = dblarr(naps)

suparray = ptrarr(naps,/ALLOCATE_HEAP)

i = 0 ; avoid loop over orders

    xguess = poly(lines,ltop[*,i]) + pixoffset        
    z      = where(finite(spectra[*,i*naps]) eq 1,count)
    good   = where(xguess gt x[z[0]] and xguess lt x[z[count-1]])
    xguess = xguess[good]
    rlines = lines[good]
    slines = rlines / ( float(homeorder)/float(orders[i]) ) 

    sxpos    = fltarr(naps,n_elements(xguess))
    sgoodbad = intarr(naps,n_elements(xguess))

    j = 0 ; loop over aps
        
        spec = reform( spectra[*,i*naps+j] )
;        good = findlines(x,spec,xguess,FWHM/2.354,GOODBAD=goodbad,$
;                         PLOT=plotlinefind,WLINES=rlines)
;        
;        sxpos[j,*]    = good
;        sgoodbad[j,*] = goodbad
        


plot, x, spec
for i=0,n_elements(xguess) do oplot, xguess[i]*[1,1], minmax(spec)

end

;================================================================


pro wavelengths2
@include

; read in the "standard" arc file
stdxd = readfits(reddatadir + 'LongXD_arc.fits', stdxdh)
stdspecx = stdxd[*,0,2]
stdspecy = stdxd[*,1,2]
res = poly_fit(stdspecx, stdspecy, 3, yfit)
stdspecy = stdspecy - yfit

; read the line list
  res_scale = 5000
  slitw_arc = 0.3
  slitw_pix = slitw_arc/0.15
  lines = rdll(filepath('lines.dat',ROOT_DIR=reddatadir),$
                RES=res_scale/1.,THRESH=0,/VACUUM)
  alines = rdll(filepath('argon_vac.dat',$
                ROOT_DIR=reddatadir+"../old-linelists/"),$
                RES=res_scale/1.,THRESH=0,/VACUUM)

; read in a skinny-slit calibration file (LSO, long6 blocker)
  arclsoon = readfits(findfilez(bdtopdir+'20021228/arc_on0413.a.fits'))
  arclsooff = readfits(findfilez(bdtopdir+'20021228/arc_off0414.b.fits'))
  arclso = arclsoon-arclsooff
  arclsospecy = total(arclso[0:1023,189:288], 2)
  
; read in another skinny-slit calibration file (LXD)
  arclxdon = readfits(findfilez(bdtopdir+'20021228/arc0274.a.fits'))
  arclxdoff = readfits(findfilez(bdtopdir+'20021228/arc0275.b.fits'))
  arclxd = arclxdon-arclxdoff
  arclxdspecy = total(arclxd[0:1023,189:288], 2)
  
; inputs for wavecal
  x = stdspecx
  spec = stdspecy
  norders = 1
  naps = 1
  ltop = reform([-4438.5844, 1491.9264], 2,1)
  pixoffset = 0.
  orders = [6]
  homeorder = 6
  FWHM = slitw_pix
  disdeg = 3
  orderdeg = 2
  robustthresh = 4.0


i = 0 ; avoid loop over orders

    xguess = poly(lines,ltop[*,i]) + pixoffset        
    z      = where(finite(spec) eq 1,count)
    good   = where(xguess gt x[z[0]] and xguess lt x[z[count-1]])
    xguess = xguess[good]
    rlines = lines[good]
    slines = rlines / ( float(homeorder)/float(orders[i]) ) 

    axguess = poly(lines,ltop[*,i]) + pixoffset        
    az      = where(finite(spec) eq 1,count)
    agood   = where(axguess gt x[az[0]] and axguess lt x[az[count-1]])
    axguess = axguess[agood]
    arlines = alines[agood]
    aslines = arlines / ( float(homeorder)/float(orders[i]) ) 

;    plot, x, spec, $
;      xr=[0,1023], /xs, xtit='Wavelength (pixels)', $
;      yr = [-200,1000], /ys, ytit='Flux (DN/s)', $
;      tit = 'LXD, Order 6 (Vacuum)'
;    for l = 0, n_elements(rlines)-1 do begin &$
;      pix = xguess[l] &$
;      oplot, pix*[1,1], [spec[pix]+100,1000], line=2 &$
;    end


    plot, x, arclsospecy
    for l = 0, n_elements(arlines)-1 do begin &$
      pix = axguess[l] &$
      oplot, pix*[1,1], [spec[pix]+100,1000], line=2 &$
    end



end


;================================================================


pro wavelengths3
@include

; read in a skinny-slit calibration file (LSO, long6 blocker)
  arclsoon = readfits(findfilez(bdtopdir+'20021228/arc_on0413.a.fits'))
  arclsooff = readfits(findfilez(bdtopdir+'20021228/arc_off0414.b.fits'))
  arclso = arclsoon-arclsooff
  arclsospecx = findgen(1024)
  arclsospecy = total(arclso[0:1023,189:288], 2)
  
; read in another skinny-slit calibration file (LXD)
  arclxdon = readfits(findfilez(bdtopdir+'20021228/arc0274.a.fits'))
  arclxdoff = readfits(findfilez(bdtopdir+'20021228/arc0275.b.fits'))
  arclxd = arclxdon-arclxdoff
  arclxdspecx = findgen(1024)
  arclxdspecy = fltarr(1024)
  topcoef = poly_fit([0,511,512,1023],[362,486,486,564],2)
  botcoef = poly_fit([0,511,512,1023],[469,588,588,662],2)
  for i=0,1023 do begin &$
    arclxdspecy[i] = total(arclxd[i,poly(i,topcoef):poly(i,botcoef)]) &$
  end

  res_scale = 5000
  slitw_arc = 0.3
  slitw_pix = slitw_arc/0.15
  lines = rdll(filepath('argon_vac.dat',$
                ROOT_DIR=reddatadir+"../old-linelists/"),$
                RES=res_scale/1.,THRESH=0,/VACUUM)

   x = arclxdspecx
   spec = arclxdspecy
   ltop = [-4438.5844, 1491.9264]
    pixoffset = -40
   xguess = poly(lines,ltop) + pixoffset
    z      = where(finite(spec) eq 1,count)
    good   = where(xguess gt x[z[0]] and xguess lt x[z[count-1]])
    xguess = xguess[good]
    rlines = lines[good]

  !p.multi=[0,1,2]
  plot, arclsospecx, arclsospecy, title='LSO'
  for l = 0, n_elements(rlines)-1 do begin &$
      pix = xguess[l] &$
      oplot, pix*[1,1], [spec[pix]+1e4,1.5e5], line=2 &$
      oplot, pix*[1,1], [-5e4,-1e4], line=2 &$
  end

   x = arclxdspecx
   spec = arclxdspecy
   ltop = [-4438.5844, 1491.9264]
   pixoffset= 10
    xguess = poly(lines,ltop)+pixoffset
    z      = where(finite(spec) eq 1,count)
    good   = where(xguess gt x[z[0]] and xguess lt x[z[count-1]])
    xguess = xguess[good]
    rlines = lines[good]
  plot, arclxdspecx, arclxdspecy,title='LXD'
  for l = 0, n_elements(rlines)-1 do begin &$
      pix = xguess[l] &$
      oplot, pix*[1,1], [-5e4,-1e3], line=2 &$
      oplot, pix*[1,1], [spec[pix]+1e4,8e4], line=2 &$
  end


end



