;+
; NAME:
;  refnet
; PURPOSE:
;  Support routine for calling ``REFNET'' to get stars from USNO A2.0 catalog.
; DESCRIPTION:
;
; CATEGORY:
;  Astrometry
;
; CALLING SEQUENCE:
;  refnet,ra,dec,width,height,bmaglim,rmaglim,starfile
;
; INPUTS:
;  ra      - Right ascension of center of field for extraction (J2000)
;              input can be in radians (double,float) or
;              a string HH:MM:SS.S  (see RAPARSE for valid syntax).
;  dec     - Declination of center of field for extraction (J2000, radians).
;              input can be in radians (double,float) or
;              a string +DD:MM:SS.S  (see DECPARSE for valid syntax).
;  width   - Width of field to extract (arcsec).
;  height  - Height of field to extract (arcsec).
;  bmaglim - Limiting Blue magnitude to extract.
;  rmaglim - Limiting Red magnitude to extract.
;  starfile- File name for the results of the catalog extraction.
;
; OPTIONAL INPUT PARAMETERS:
;
; KEYWORD INPUT PARAMETERS:
;
; OUTPUTS:
;  The output is all to the file and contains a list of stars from the
;    USNO A2.0 catalog according to the input constraints.
;
; KEYWORD OUTPUT PARAMETERS:
;
; COMMON BLOCKS:
;
; SIDE EFFECTS:
;
; RESTRICTIONS:
;  Currently this is rather restricted and is just an initial working version.
;  This is hardcoded to a specific location for the catalog and executable.
;  This program will work only on Unix platforms at present.
;  You must define an evironment variable, USNO_CAT, that points to the
;  directory where the data live.  Default is the current directory.
;
; PROCEDURE:
;
; MODIFICATION HISTORY:
;  97/05/08, Written by Marc W. Buie, Lowell Observatory
;  97/11/24 - MWB - Added CATPATH keyword
;  99/06/22, MWB, changed CATPATH default
;  02/02/06, MWB, rewrite for new refnet version
;
;-
pro refnet,ra,dec,width,height,bmaglim,rmaglim,starfile

   if badpar(ra,[4,5,7],0,CALLER='REFNET: (ra) ',TYPE=ratype) then return
   if badpar(dec,[4,5,7],0,CALLER='REFNET: (dec) ',TYPE=dectype) then return

   if ratype  ne 7 then rastr,ra,1,ras else ras = ra
   if dectype ne 7 then decstr,dec,0,decs else decs = dec

   spawn,'refnet -ra '+ras+' -dec '+decs+' -w '+string(width)+ $
                 ' -h '+string(height)+' -b '+string(bmaglim)+ $
                 ' -r '+string(rmaglim)+' > '+starfile
end
